# azion-api-client

**A Python API client for Azion management and automation**

## Installation

```bash
pip install azion-api-client
```

## Documentation

It's a WIP. The idea is to provide python interaction to the Azion API, but at the same time, to expose an `azion` binary to pass some commands.

## Contributing

```bash
python -m venv .venv
source .venv/bin/activate
pip install -r requirements-development.txt
```

## Acknowledgments

This package is based on previous work done at:

- [mauricioabreu/azion-python](https://github.com/mauricioabreu/azion-python)
- [chaordic/azion-python-sdk](https://github.com/chaordic/azion-python-sdk)
